summaryrefslogtreecommitdiff
path: root/popt
diff options
context:
space:
mode:
authorjbj <devnull@localhost>2001-04-29 01:05:43 +0000
committerjbj <devnull@localhost>2001-04-29 01:05:43 +0000
commit3b5820c4205e440d9aad5c5d626721ee30b12292 (patch)
treeb1f0a694903aef1dd937539e1b06c8b0947fb67c /popt
parent6a0524ed57548de92daa4b6cf8ee9d2ab39d7a42 (diff)
downloadrpm-3b5820c4205e440d9aad5c5d626721ee30b12292.tar.gz
rpm-3b5820c4205e440d9aad5c5d626721ee30b12292.tar.bz2
rpm-3b5820c4205e440d9aad5c5d626721ee30b12292.zip
- globalize _free(3) wrapper in rpmlib.h, consistent usage throughout.
- internalize locale insensitive ctype(3) in rpmio.h - boring lclint annotations and fiddles. CVS patchset: 4721 CVS date: 2001/04/29 01:05:43
Diffstat (limited to 'popt')
-rw-r--r--popt/popt.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/popt/popt.h b/popt/popt.h
index f66db84f3..70bb40869 100644
--- a/popt/popt.h
+++ b/popt/popt.h
@@ -169,9 +169,11 @@ typedef void (*poptCallbackType) (poptContext con,
* @param flags or'd POPT_CONTEXT_* bits
* @return initialized popt context
*/
-/*@only@*/ poptContext poptGetContext(/*@keep@*/ const char * name,
- int argc, /*@keep@*/ const char ** argv,
- /*@keep@*/ const struct poptOption * options, int flags);
+/*@only@*/ poptContext poptGetContext(
+ /*@dependent@*/ /*@keep@*/ const char * name,
+ int argc, /*@dependent@*/ /*@keep@*/ const char ** argv,
+ /*@dependent@*/ /*@keep@*/ const struct poptOption * options,
+ int flags);
/** \ingroup popt
* Reinitialize popt context.